pg.ddx.io  pgsql-performance@postgresql.org mailing list archive  
help / color / mirror / Atom feed
From: Jean-Pierre Pelletier <pelletier_32@sympatico.ca>
To: John Arbash Meinel <john@arbash-meinel.com>
Cc: pgsql-performance@postgresql.org
Subject: Re: Queries 15 times slower on 8.1 beta 2 than on 8.0
Date: Thu, 22 Sep 2005 17:58:49 -0400
Message-ID: <BAYC1-PASMTP0276B50280C40ABC9BBCB495970@CEZ.ICE> (raw)
References: <BAYC1-PASMTP01EE67AD3A0034394D85D895970@CEZ.ICE>
	<433326A6.8010708@arbash-meinel.com>

Here are the explain analyze:

On 8.1 beta2:

"Nested Loop Left Join  (cost=0.00..18591.77 rows=1 width=0) (actual 
time=1320.302..2439.066 rows=1 loops=1)"
"  Join Filter: ("outer".priceid = "inner".priceid)"
"  ->  Nested Loop Left Join  (cost=0.00..5.59 rows=1 width=4) (actual 
time=0.044..0.058 rows=1 loops=1)"
"        ->  Seq Scan on content c  (cost=0.00..1.01 rows=1 width=8) (actual 
time=0.009..0.011 rows=1 loops=1)"
"        ->  Index Scan using "Supplier Id" on supplier s  (cost=0.00..4.56 
rows=1 width=4) (actual time=0.016..0.022 rows=1 loops=1)"
"              Index Cond: ("outer".supplierid = s.supplierid)"
"  ->  Seq Scan on price p  (cost=0.00..11317.75 rows=581475 width=4) 
(actual time=0.004..1143.720 rows=581475 loops=1)"
"Total runtime: 2439.211 ms"

On 8.0.1:

"Nested Loop Left Join  (cost=0.00..11.02 rows=1 width=0) (actual 
time=0.000..0.000 rows=1 loops=1)"
"  ->  Nested Loop Left Join  (cost=0.00..5.48 rows=1 width=4) (actual 
time=0.000..0.000 rows=1 loops=1)"
"        ->  Seq Scan on content c  (cost=0.00..1.01 rows=1 width=8) (actual 
time=0.000..0.000 rows=1 loops=1)"
"        ->  Index Scan using "Supplier Id" on supplier s  (cost=0.00..4.46 
rows=1 width=4) (actual time=0.000..0.000 rows=1 loops=1)"
"              Index Cond: ("outer".supplierid = s.supplierid)"
"  ->  Index Scan using "Price Id" on price p  (cost=0.00..5.53 rows=1 
width=4) (actual time=0.000..0.000 rows=1 loops=1)"
"        Index Cond: ("outer".priceid = p.priceid)"
"Total runtime: 0.000 ms"

----- Original Message ----- 
From: "John Arbash Meinel" <john@arbash-meinel.com>
To: "Jean-Pierre Pelletier" <pelletier_32@sympatico.ca>
Cc: <pgsql-performance@postgresql.org>
Sent: Thursday, September 22, 2005 5:48 PM
Subject: Re: [PERFORM] Queries 15 times slower on 8.1 beta 2 than on 8.0





view thread (21+ messages)  latest in thread

Message-ID: <BAYC1-PASMTP0276B50280C40ABC9BBCB495970@CEZ.ICE>
Permalink:  ../BAYC1-PASMTP0276B50280C40ABC9BBCB495970@CEZ.ICE/
Also on:    postgresql.org/message-id/BAYC1-PASMTP0276B50280C40ABC9BBCB495970@CEZ.ICE

 · 

reply

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Reply to all the recipients using the --to and --cc options:
  reply via email

  To: pgsql-performance@postgresql.org
  Cc: pelletier_32@sympatico.ca, john@arbash-meinel.com
  Subject: Re: Queries 15 times slower on 8.1 beta 2 than on 8.0
  In-Reply-To: <BAYC1-PASMTP0276B50280C40ABC9BBCB495970@CEZ.ICE>

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

This inbox is served by DDX for PostgreSQL; see mirroring instructions
for how to clone and mirror all data and code used for this inbox